@@ -162,6 +162,12 @@ either as C extensions or in pure Python).
 '''
 
 # ....................{ TYPES ~ core : singleton          }....................
+EllipsisType: Any = type(Ellipsis)
+'''
+Type of the ``Ellipsis`` singleton.
+'''
+
+
 NoneType: Any = type(None)
 '''
 Type of the ``None`` singleton.
@@ -225,8 +231,8 @@ standard functions,** including:
 * **Unbound instance methods** (i.e., instance methods accessed on their
   declaring classes rather than bound instances).
 * **Static methods** (i.e., methods decorated with the builtin
-  :func:`staticmethod` decorator regardless of whether accessed on their
-  declaring classes or associated instances).
+  :func:`staticmethod` decorator, regardless of those methods are accessed on
+  their declaring classes or associated instances).
 
 **This type matches no callables whatsoever under some non-CPython
 interpreters,** including:
@@ -885,11 +891,11 @@ To distinguish between the various semantic types of hints ambiguously matched
 by this type, higher-level PEP-specific functions *must* be called instead.
 These include:
 
-* :func:`beartype._util.hint.pep.proposal.utilhintpep484.is_hint_pep484_generic`.
+* :func:`beartype._util.hint.pep.proposal.utilpep484.is_hint_pep484_generic`.
   detecting `PEP 484`_-compliant generic type hints.
-* :func:`beartype._util.hint.pep.proposal.utilhintpep585.is_hint_pep585_builtin`.
+* :func:`beartype._util.hint.pep.proposal.utilpep585.is_hint_pep585_builtin`.
   detecting `PEP 585`_-compliant builtin type hints.
-* :func:`beartype._util.hint.pep.proposal.utilhintpep585.is_hint_pep585_generic`.
+* :func:`beartype._util.hint.pep.proposal.utilpep585.is_hint_pep585_generic`.
   detecting `PEP 585`_-compliant generic type hints.
 
 .. _PEP 484:
@@ -1213,6 +1219,12 @@ callable objects implemented in low-level C rather than high-level Python).
 '''
 
 
+CallableOrClassTypes = CallableTypes + (ClassType,)
+'''
+Tuple of all callable types as well as the type of all types.
+'''
+
+
 CallableOrStrTypes = CallableTypes + (StrType,)
 '''
 Tuple of all callable types as well as the string type.
