@@ -14,37 +14,25 @@ This private submodule is *not* intended for importation by downstream callers.
 
 # ....................{ IMPORTS                           }....................
 from beartype.roar._roarexc import _BeartypeCallHintPepRaiseException
-from beartype._cave._cavefast import NoneType
 from beartype._cave._cavemap import NoneTypeOr
-from beartype._util.hint.pep.proposal.utilhintpep484 import (
-    get_hint_pep484_newtype_class,
-    is_hint_pep484_newtype,
+from beartype._data.hint.pep.sign.datapepsignset import (
+    HINT_SIGNS_SUPPORTED_DEEP,
+    HINT_SIGNS_TYPE_STDLIB,
 )
-from beartype._util.hint.pep.proposal.utilhintpep544 import (
-    get_hint_pep544_io_protocol_from_generic,
-    is_hint_pep544_io_generic,
-)
-from beartype._util.hint.pep.proposal.utilhintpep593 import (
-    get_hint_pep593_metahint,
-    is_hint_pep593,
-    is_hint_pep593_beartype,
-)
-from beartype._util.hint.pep.utilhintpepget import (
+from beartype._util.hint.utilhintget import get_hint_reduced
+from beartype._util.hint.pep.utilpepget import (
     get_hint_pep_args,
     get_hint_pep_generic_bases_unerased,
     get_hint_pep_sign,
 )
-from beartype._util.hint.pep.utilhintpeptest import (
+from beartype._util.hint.pep.utilpeptest import (
     is_hint_pep,
     is_hint_pep_generic,
-    is_hint_pep_tuple_empty,
-    is_hint_pep_typevar,
+    is_hint_pep_subscripted,
 )
-from beartype._util.hint.utilhinttest import (
-    is_hint_forwardref,
-    is_hint_ignorable,
-)
-from typing import Any, Callable, NoReturn, Optional, Tuple
+from beartype._util.hint.utilhinttest import is_hint_ignorable
+from beartype._util.py.utilpyversion import IS_PYTHON_AT_LEAST_3_7
+from typing import Any, Callable, Optional, Tuple
 
 # See the "beartype.cave" submodule for further commentary.
 __all__ = ['STAR_IMPORTS_CONSIDERED_HARMFUL']
@@ -83,7 +71,7 @@ class CauseSleuth(object):
             as superclasses prior to their implicit type erasure by the
             :mod:`typing` module) subclassed by this generic.
           * Else, the possibly empty tuple of all arguments subscripting this
-            hint if this
+            hint.
 
         * Else, ``None``.
     pith : Any
@@ -188,59 +176,9 @@ class CauseSleuth(object):
         Set the type hint to validate this object against.
         '''
 
-        # ................{ REDUCTION                         }................
-        #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
-        # CAVEATS: Synchronize changes here with the corresponding block of the
-        # beartype._decor._code._pep._pephint.pep_code_check_hint() function.
-        #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
-        #
-        # This logic reduces the currently visited hint to an arbitrary object
-        # associated with this hint when this hint conditionally satisfies any
-        # of various conditions.
-        #
-        # ................{ REDUCTION ~ pep 484 ~ none        }................
-        # If this is the PEP 484-compliant "None" singleton, reduce this hint
-        # to the type of that singleton. While not explicitly defined by the
-        # "typing" module, PEP 484 explicitly supports this singleton:
-        #     When used in a type hint, the expression None is considered
-        #     equivalent to type(None).
-        if hint is None:
-            hint = NoneType
-        # ................{ REDUCTION ~ pep 593               }................
-        # If this is a PEP 593-compliant type metahint, ignore all annotations
-        # on this hint (i.e., "hint_curr.__metadata__" tuple) by reducing this
-        # hint to its origin (e.g., "str" in "Annotated[str, 50, False]").
-        elif is_hint_pep593(hint):
-            # If the first argument subscripting this metahint is
-            # beartype-agnostic (e.g., *NOT* an instance of the
-            # "beartype.vale._SubscriptedIs" class produced by subscripting the
-            # "Is" class), ignore all annotations on this hint by reducing this
-            # hint to its origin (e.g., "str" in "Annotated[str, 50, False]").
-            if not is_hint_pep593_beartype(hint):
-                hint = get_hint_pep593_metahint(hint)
-            # Else, that argument is beartype-specific. In this case, preserve
-            # this hint as is for subsequent handling below.
-        # ................{ REDUCTION ~ pep 544               }................
-        # If this is a PEP 484-compliant IO generic base class *AND* the active
-        # Python interpreter targets at least Python >= 3.8 and thus supports
-        # PEP 544-compliant protocols, reduce this functionally useless hint to
-        # the corresponding functionally useful beartype-specific PEP
-        # 544-compliant protocol implementing this hint.
-        #
-        # Note that PEP 484-compliant IO generic base classes are technically
-        # usable under Python < 3.8 (e.g., by explicitly subclassing those
-        # classes from third-party classes). Ergo, we can neither safely emit
-        # warnings nor raise exceptions on visiting these classes under *ANY*
-        # Python version.
-        elif is_hint_pep544_io_generic(hint):
-            hint = get_hint_pep544_io_protocol_from_generic(hint)
-        # ................{ REDUCTION ~ pep 484 ~ new type    }................
-        # If this is a PEP 484-compliant new type hint, reduce this hint to the
-        # user-defined class aliased by this hint. Although this logic could
-        # also be performed below, doing so here simplifies matters.
-        elif is_hint_pep484_newtype(hint):
-            hint = get_hint_pep484_newtype_class(hint)
-        # ................{ REDUCTION ~ end                   }................
+        # Reduce the currently visited hint to a lower-level hint-like object
+        # associated with this hint if this hint satisfies a condition.
+        hint = get_hint_reduced(hint=hint, hint_label=self.exception_label)
 
         # If this hint is PEP-compliant...
         if is_hint_pep(hint):
@@ -285,7 +223,7 @@ class CauseSleuth(object):
         and the list ``list(range(256)) + [False,]`` consisting of the integers
         0 through 255 followed by boolean ``False``. Since this list is a
         standard sequence, the
-        :func:`._peperrorsequence.get_cause_or_none_sequence_standard`
+        :func:`._peperrorsequence.get_cause_or_none_sequence_args_1`
         function must decide the cause of this list's failure to comply with
         this hint by finding the list item that is neither an integer nor a
         string, implemented by by iteratively passing each list item to the
@@ -293,7 +231,7 @@ class CauseSleuth(object):
         the first 256 items of this list are integers satisfying this hint,
         :func:`._peperrorunion.get_cause_or_none_union` returns
         ``None`` to
-        :func:`._peperrorsequence.get_cause_or_none_sequence_standard`
+        :func:`._peperrorsequence.get_cause_or_none_sequence_args_1`
         before finally finding the non-compliant boolean item and returning the
         human-readable cause.
 
@@ -317,7 +255,7 @@ class CauseSleuth(object):
         '''
 
         # Getter function returning the desired string.
-        get_cause_or_none = None
+        get_cause_or_none: Callable[[CauseSleuth], Optional[str]] = None  # type: ignore[assignment]
 
         # If this hint is ignorable, all possible objects satisfy this hint,
         # implying this hint *CANNOT* by definition be the cause of this
@@ -326,78 +264,68 @@ class CauseSleuth(object):
             return None
         # Else, this hint is unignorable.
         #
-        # If *NO* sign uniquely identifies this hint, this hint is
-        # PEP-noncompliant. In this case...
+        # If *NO* sign uniquely identifies this hint, this hint is either
+        # PEP-noncompliant *OR* only contextually PEP-compliant in certain
+        # specific use cases. In either case...
         elif self.hint_sign is None:
-            # Avoid circular import dependencies.
-            from beartype._decor._error._errortype import (
-                get_cause_or_none_type,
-                get_cause_or_none_types,
-            )
-
-            # Defer to the getter function supporting either...
-            get_cause_or_none = (
-                # If this hint is a tuple union, tuples of one or more
-                # isinstanceable classes.
-                get_cause_or_none_types
-                if isinstance(self.hint, tuple) else
-                # Else, isinstanceable classes under the generous assumption
-                # this this hint is a type. If this is *NOT* the case, this
-                # getter will raise a human-readable exception.
-                get_cause_or_none_type
-            )
-        # Else, this hint is PEP-compliant.
-        #
-        # If this PEP-compliant hint is its own unsubscripted "typing"
-        # attribute (e.g., "typing.List" rather than "typing.List[str]") and is
-        # thus subscripted by *NO* child hints...
-        elif self.hint is self.hint_sign:
-            # If this hint is the non-standard "typing.NoReturn" type hint
-            # specific to return values...
-            if self.hint is NoReturn:
+            # If this hint is a tuple union...
+            if isinstance(self.hint, tuple):
                 # Avoid circular import dependencies.
-                from beartype._decor._error._proposal._errorpep484noreturn import (
-                    get_cause_or_none_noreturn)
+                from beartype._decor._error._errortype import (
+                    get_cause_or_none_types)
 
-                # Defer to the getter function specific to this hint.
-                get_cause_or_none = get_cause_or_none_noreturn
-            # Else, this hint is a standard PEP-compliant type hint supported
-            # by both parameters and return values. In this case, we assume
-            # this hint to originate from an origin type.
+                # Defer to the getter function specific to tuple unions.
+                get_cause_or_none = get_cause_or_none_types
+            # Else, this hint *NOT* is a tuple union. In this case, assume this
+            # hint to be an isinstanceable class. If this is *NOT* the case,
+            # the getter deferred to below raises a human-readable exception.
             else:
                 # Avoid circular import dependencies.
                 from beartype._decor._error._errortype import (
-                    get_cause_or_none_type_origin)
+                    get_cause_or_none_type)
 
-                # Defer to the getter function supporting hints originating
-                # from origin types.
-                get_cause_or_none = get_cause_or_none_type_origin
-        # Else, this PEP-compliant hint is *NOT* its own unsubscripted "typing"
-        # attribute. In this case...
+                # Defer to the getter function specific to classes.
+                get_cause_or_none = get_cause_or_none_type
+        # Else, this hint is PEP-compliant.
+        #
+        # If this hint is neither...
+        elif (
+            # Originates from an origin type and may thus be shallowly
+            # type-checked against that type *AND is either...
+            self.hint_sign in HINT_SIGNS_TYPE_STDLIB and (
+                #FIXME: Ideally, this line should just resemble:
+                #    not is_hint_pep_subscripted(hint_curr)
+                #Unfortunately, unsubscripted type hints under Python 3.6
+                #like "typing.List" are technically subscripted due to
+                #subclassing subscripted superclasses, which is insane. Due
+                #to this insanity, we currently ignore type variables for
+                #purposes of detecting subscription. Since this is awful,
+                #drop this as soon as we drop Python 3.6 support.
+                # Unsubscripted *OR*...
+                not (
+                    is_hint_pep_subscripted(self.hint)
+                    if IS_PYTHON_AT_LEAST_3_7 else
+                    len(self.hint_childs)
+                ) or
+                #FIXME: Remove this branch *AFTER* deeply supporting all
+                #hints.
+                # Currently unsupported with deep type-checking...
+                self.hint_sign not in HINT_SIGNS_SUPPORTED_DEEP
+            )
+        # Then this hint is both unsubscripted and originating from a standard
+        # type origin. In this case, this hint was type-checked shallowly.
+        ):
+            # Avoid circular import dependencies.
+            from beartype._decor._error._errortype import (
+                get_cause_or_none_type_stdlib)
+
+            # Defer to the getter function supporting hints originating
+            # from origin types.
+            get_cause_or_none = get_cause_or_none_type_stdlib
+        # Else, this hint is either subscripted *OR* unsubscripted but not
+        # originating from a standard type origin. In either case, this hint
+        # was type-checked deeply.
         else:
-            # If this hint is neither...
-            if not (
-                # Subscripted by no child hints *NOR*...
-                self.hint_childs or
-                # An empty fixed-length tuple hint, whose PEP 585 (but *NOT*
-                # PEP 484)-compliant implementation is subscripted by no child
-                # hints *NOR*...
-                is_hint_pep_tuple_empty(self.hint) or
-                # A forward reference nor type variable, whose designs reside
-                # well outside the standard "typing" dunder variable API and
-                # are thus *NEVER* subscripted by child hints...
-                is_hint_forwardref(self.hint) or
-                is_hint_pep_typevar(self.hint)
-            ):
-            # Then this hint should have been subscripted by one or more child
-            # hints but wasn't. In this case, raise an exception.
-                raise _BeartypeCallHintPepRaiseException(
-                    f'{self.exception_label} PEP type hint '
-                    f'{repr(self.hint)} unsubscripted.'
-                )
-            # Else, this hint is subscripted by one or more child hints (e.g.,
-            # "typing.List[str]" rather than "typing.List").
-
             # Avoid circular import dependencies.
             from beartype._decor._error.errormain import (
                 PEP_HINT_SIGN_TO_GET_CAUSE_FUNC)
@@ -405,13 +333,13 @@ class CauseSleuth(object):
             # Getter function returning the desired string for this attribute
             # if any *OR* "None" otherwise.
             get_cause_or_none = PEP_HINT_SIGN_TO_GET_CAUSE_FUNC.get(
-                self.hint_sign, None)
+                self.hint_sign, None)  # type: ignore[arg-type]
 
             # If no such function has been implemented to handle this attribute
             # yet, raise an exception.
             if get_cause_or_none is None:
                 raise _BeartypeCallHintPepRaiseException(
-                    f'{self.exception_label} PEP type hint '
+                    f'{self.exception_label} type hint '
                     f'{repr(self.hint)} unsupported (i.e., no '
                     f'"get_cause_or_none_"-prefixed getter function defined '
                     f'for this category of hint).'
