@@ -13,19 +13,17 @@ This private submodule is *not* intended for importation by downstream callers.
 # ....................{ IMPORTS                           }....................
 from beartype.roar import BeartypeDecorHintForwardRefException
 from beartype._util.cache.utilcachecall import callable_cached
-from beartype._util.hint.nonpep.utilhintnonpeptest import (
+from beartype._util.hint.nonpep.utilnonpeptest import (
     die_unless_hint_nonpep,
     is_hint_nonpep,
 )
-from beartype._util.hint.pep.utilhintpeptest import (
+from beartype._util.hint.pep.utilpeptest import (
     die_if_hint_pep_unsupported,
     is_hint_pep,
     is_hint_pep_supported,
 )
-from beartype._util.hint.data.utilhintdata import (
-    HINT_BASES_FORWARDREF,
-    HINTS_IGNORABLE_SHALLOW,
-)
+from beartype._data.hint.datahint import HINT_BASES_FORWARDREF
+from beartype._data.hint.pep.datapeprepr import HINTS_REPR_IGNORABLE_SHALLOW
 
 # See the "beartype.cave" submodule for further commentary.
 __all__ = ['STAR_IMPORTS_CONSIDERED_HARMFUL']
@@ -177,42 +175,30 @@ def is_hint(hint: object) -> bool:
 @callable_cached
 def is_hint_ignorable(hint: object) -> bool:
     '''
-    ``True`` only if the passed object is an **ignorable type hint.**
+    ``True`` only if the passed type hint is **ignorable.**
 
     This tester function is memoized for efficiency.
 
     Parameters
     ----------
     hint : object
-        Object to be inspected.
+        Type hint to be inspected.
 
     Returns
     ----------
     bool
-        ``True`` only if this object is an ignorable type hint.
-
-    Raises
-    ----------
-    TypeError
-        If this object is **unhashable** (i.e., *not* hashable by the builtin
-        :func:`hash` function and thus unusable in hash-based containers like
-        dictionaries and sets). All supported type hints are hashable.
+        ``True`` only if this type hint is ignorable.
     '''
 
-    # Attempt to...
-    try:
-        # If this hint is shallowly ignorable, return true.
-        if hint in HINTS_IGNORABLE_SHALLOW:
-            return True
-        # Else, this hint is *NOT* shallowly ignorable.
-    # If this hint is unhashable, hint is *NOT* shallowly ignorable.
-    except TypeError:
-        pass
+    # If this hint is shallowly ignorable, return true.
+    if repr(hint) in HINTS_REPR_IGNORABLE_SHALLOW:
+        return True
+    # Else, this hint is *NOT* shallowly ignorable.
 
     # If this hint is PEP-compliant...
     if is_hint_pep(hint):
         # Avoid circular import dependencies.
-        from beartype._util.hint.pep.utilhintpeptest import (
+        from beartype._util.hint.pep.utilpeptest import (
             is_hint_pep_ignorable)
 
         # Defer to the function testing whether this hint is an ignorable
