@@ -33,6 +33,14 @@ IS_PYTHON_AT_LEAST_3_10 = IS_PYTHON_AT_LEAST_4_0 or version_info >= (3, 10)
 '''
 
 
+#FIXME: After dropping Python 3.9 support:
+#* Remove this global.
+IS_PYTHON_AT_MOST_3_9 = not IS_PYTHON_AT_LEAST_3_10
+'''
+``True`` only if the active Python interpreter targets at most Python 3.9.x.
+'''
+
+
 #FIXME: After dropping Python 3.8 support:
 #* Refactor all code conditionally testing this global to be unconditional.
 #* Remove this global.
@@ -44,6 +52,14 @@ IS_PYTHON_AT_LEAST_3_9 = IS_PYTHON_AT_LEAST_3_10 or version_info >= (3, 9)
 '''
 
 
+#FIXME: After dropping Python 3.8 support:
+#* Remove this global.
+IS_PYTHON_AT_MOST_3_8 = not IS_PYTHON_AT_LEAST_3_9
+'''
+``True`` only if the active Python interpreter targets at most Python 3.8.x.
+'''
+
+
 #FIXME: After dropping Python 3.7 support:
 #* Refactor all code conditionally testing this global to be unconditional.
 #* Remove this global.
