@@ -97,6 +97,7 @@ from beartype._cave._cavefast import (
     ClassType,
     CollectionType,
     ContainerType,
+    EllipsisType,
     EnumType,
     EnumMemberType,
     FileType,
@@ -139,6 +140,7 @@ from beartype._cave._cavefast import (
     AsyncCTypes,
     BoolOrNumberTypes,
     CallableCTypes,
+    CallableOrClassTypes,
     CallableOrStrTypes,
     CallableTypes,
     DecoratorTypes,
