@@ -37,7 +37,8 @@ of Life (EoL) (e.g., Python 3.5) are explicitly unsupported.
 #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
 import sys as _sys
-from beartype._util.py.utilpyinterpreter import IS_PYPY as _IS_PYPY
+from beartype._util.os.utilostest import is_os_macos as _is_os_macos
+from beartype._util.py.utilpyinterpreter import is_py_pypy as _is_py_pypy
 from typing import Tuple as _Tuple
 
 # See the "beartype.cave" submodule for further commentary.
@@ -65,7 +66,7 @@ Human-readable name of the license this package is licensed under.
 #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 # WARNING: Changes to this section *MUST* be synchronized with:
 # * Signs declared by the private
-#   "beartype._util.data.hint.pep.datapepsign" submodule, which *MUST*
+#   "beartype._data.hint.pep.datapepsign" submodule, which *MUST*
 #   be synchronized against the "__all__" dunder list global of the "typing"
 #   module bundled with the most recent CPython release.
 # * Continuous integration test matrices, including:
@@ -114,6 +115,13 @@ tuple of integers.
 '''
 
 
+_PYTHON_VERSION_PARTS = _sys.version_info[:3]
+'''
+Machine-readable current version of the active Python interpreter as a
+tuple of integers.
+'''
+
+
 # Validate the version of the active Python interpreter *BEFORE* subsequent
 # code possibly depending on this version. Since this version should be
 # validated both at setuptools-based install time and post-install runtime
@@ -149,7 +157,7 @@ tuple of integers.
 # call to setup() in "setup.py" (e.g., "requires_python = ['>=2.2.1'],"), that
 # field has yet to be integrated into either disutils or setuputils. Hence,
 # that field is validated manually in the typical way.
-if _sys.version_info[:3] < PYTHON_VERSION_MIN_PARTS:
+if _PYTHON_VERSION_PARTS < PYTHON_VERSION_MIN_PARTS:
     # Human-readable current version of Python. Ideally, "sys.version" would be
     # leveraged here instead; sadly, that string embeds significantly more than
     # merely a version and hence is inapplicable for real-world usage: e.g.,
@@ -192,7 +200,7 @@ if _sys.version_info[:3] < PYTHON_VERSION_MIN_PARTS:
 # For further details, see http://semver.org.
 #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
-VERSION = '0.7.1'
+VERSION = '0.8.0'
 '''
 Human-readable package version as a ``.``-delimited string.
 '''
@@ -271,7 +279,32 @@ URL of this package's release list.
 '''
 
 # ....................{ METADATA ~ libs : runtime         }....................
-LIBS_RUNTIME_OPTIONAL = ()
+_LIB_RUNTIME_OPTIONAL_VERSION_MINIMUM_NUMPY = '1.21.0'
+'''
+Minimum optional version of NumPy recommended for use with mod:`beartype`.
+
+NumPy >= 1.21.0 first introduced the third-party PEP-noncompliant
+:attr:`numpy.typing.NDArray` type hint supported by the
+:func:`beartype.beartype` decorator.
+'''
+
+
+_LIB_RUNTIME_OPTIONAL_VERSION_MINIMUM_TYPING_EXTENSIONS = '3.10.0.0'
+'''
+Minimum optional version of the third-party :mod:`typing_extensions` package
+recommended for use with mod:`beartype`.
+
+:mod:`typing_extensions` >= 3.10.0.0 backports all :mod:`typing` attributes
+unavailable under older Python interpreters supported by the
+:func:`beartype.beartype` decorator .
+'''
+
+
+# Note that we intentionally omit NumPy here. If you want it, you're already
+# using it; likewise, if you don't want it, you're *NOT* already using it.
+LIBS_RUNTIME_OPTIONAL = (
+    f'typing_extensions >={_LIB_RUNTIME_OPTIONAL_VERSION_MINIMUM_TYPING_EXTENSIONS}',
+)
 '''
 Optional runtime package dependencies as a tuple of :mod:`setuptools`-specific
 requirements strings of the format ``{project_name}
@@ -292,27 +325,68 @@ requirements strings of the format ``{project_name}
 '''
 
 # ....................{ METADATA ~ libs : test            }....................
-_LIBS_TESTTIME_MANDATORY_MYPY = (
-    # A *VERY* modern version of mypy is recommended. Even fairly recent older
-    # versions of mypy are significantly deficient with respect to error
-    # reporting to the point of uselessness.
-    'mypy >=0.800' ,
-) if not _IS_PYPY else ()
+#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+# CAUTION: Avoid constraining optional test-time dependencies to version
+# ranges, which commonly fail for edge-case test environments -- including:
+# * The oldest Python version still supported by @beartype, which typically is
+#   *NOT* supported by newer versions of these dependencies.
+#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+LIBS_TESTTIME_OPTIONAL = (
+    'typing_extensions',
+) + (
+    # If the active Python interpreter is *NOT* PyPy...
+    (
+        # mypy >= 0.800, a reasonably recent version known to behave well. Even
+        # less reasonably recent versions of mypy are significantly deficient
+        # with respect to error reporting and *MUST* thus be blacklisted.
+        'mypy >=0.800' ,
+        # If the current platform is *NOT* macOS...
+        (
+            # NumPy. NumPy has become *EXTREMELY* non-trivial to install under
+            # macOS with "pip", due to the conjunction of multiple issues:
+            # * NumPy > 1.18.0, whose initial importation now implicitly
+            #   detects whether the BLAS implementation NumPy was linked
+            #   against is sane and raises a "RuntimeError" exception if that
+            #   implementation is insane resembling:
+            #       RuntimeError: Polyfit sanity test emitted a warning, most
+            #       likely due to using a buggy Accelerate backend. If you
+            #       compiled yourself, more information is available at
+            #       https://numpy.org/doc/stable/user/building.html#accelerated-blas-lapack-libraries
+            #       Otherwise report this to the vendor that provided NumPy.
+            #       RankWarning: Polyfit may be poorly conditioned
+            # * Apple's blatantly broken multithreaded implementation of their
+            #   "Accelerate" BLAS replacement, which neither NumPy nor "pip"
+            #   have *ANY* semblance of control over.
+            # * "pip" under PyPy, which for unknown reasons fails to properly
+            #   install NumPy even when the "--force-reinstall" option is
+            #   explicitly passed to "pip". Oddly, passing that option to "pip"
+            #   under CPython resolves this issue -- which is why we only
+            #   selectively disable NumPy installation under macOS + PyPy.
+            #
+            # See also this upstream NumPy issue:
+            #     https://github.com/numpy/numpy/issues/15947
+            'numpy',
+        ) if not _is_os_macos() else
+        # Else, the active Python interpreter is PyPy under macOS and thus
+        # fails to support NumPy. In this case, avoid requiring NumPy.
+        ()
+    ) if not _is_py_pypy() else
+    # Else, the active Python interpreter is PyPy and thus fails to support
+    # mypy. In this case, avoid requiring mypy. See also this official
+    # documentation discussing mypy's current incompatibility with PyPy:
+    #     https://mypy.readthedocs.io/en/stable/faq.html#does-it-run-on-pypy
+    ()
+)
 '''
-**Mandatory mypy test-time package dependency** (i.e., dependencies required
-to test this package under :mod:`tox`) as a tuple of :mod:`setuptools`-specific
-requirements strings of the format ``{project_name}
-{comparison1}{version1},...,{comparisonN}{versionN}`` if the active Python
-interpreter is not PyPy *or* the empty tuple otherwise (i.e., if this
-interpreter is PyPy).
+**Optional developer test-time package dependencies** (i.e., dependencies
+recommended to test this package with :mod:`tox` as a developer at the command
+line) as a tuple of :mod:`setuptools`-specific requirements strings of the
+format ``{project_name} {comparison1}{version1},...,{comparisonN}{versionN}``.
 
 See Also
 ----------
 :data:`LIBS_RUNTIME_OPTIONAL`
     Further details.
-https://mypy.readthedocs.io/en/stable/faq.html#does-it-run-on-pypy
-    Official documentation discussing mypy's current incompatibility with PyPy
-    to presumably be fixed at some future point.
 '''
 
 
@@ -332,7 +406,12 @@ See Also
 '''
 
 
-LIBS_TESTTIME_MANDATORY_TOX = _LIBS_TESTTIME_MANDATORY_MYPY + (
+# For completeness, install *ALL* optional test-time dependencies into *ALL*
+# isolated virtual environments managed by "tox". Failure to list *ALL*
+# optional test-time dependencies here commonly results in errors from mypy,
+# which raises false positives on parsing "import" statements for currently
+# uninstalled third-party packages (e.g., "import numpy as np").
+LIBS_TESTTIME_MANDATORY_TOX = LIBS_TESTTIME_OPTIONAL + (
     'pytest >=4.0.0',
 )
 '''
@@ -348,24 +427,9 @@ See Also
 '''
 
 
-LIBS_TESTTIME_OPTIONAL = ()
-'''
-**Optional developer test-time package dependencies** (i.e., dependencies
-recommended to test this package with :mod:`tox` as a developer at the command
-line) as a tuple of :mod:`setuptools`-specific requirements strings of the
-format ``{project_name} {comparison1}{version1},...,{comparisonN}{versionN}``.
-
-See Also
-----------
-:data:`LIBS_RUNTIME_OPTIONAL`
-    Further details.
-'''
-
-
 LIBS_TESTTIME_MANDATORY = (
     LIBS_TESTTIME_MANDATORY_COVERAGE +
-    LIBS_TESTTIME_MANDATORY_TOX +
-    LIBS_TESTTIME_OPTIONAL + (
+    LIBS_TESTTIME_MANDATORY_TOX + (
         # A relatively modern version of tox is required.
         'tox >=3.20.1',
     )
@@ -383,10 +447,15 @@ See Also
 '''
 
 # ....................{ METADATA ~ libs : doc             }....................
-_LIB_VERSION_MIN_SPHINX = '3.4.3'
+_LIB_VERSION_MIN_SPHINX = '4.1.0'
 '''
 Human-readable minimum version as a ``.``-delimited string of :mod:`sphinx`
 required to build package documentation.
+
+Specifically, this project requires:
+
+* :mod:sphinx` >= 4.1.0, which first supported the
+  ``autodoc_typehints = 'both'`` option.
 '''
 
 
