@@ -17,9 +17,9 @@ from beartype._cave._cavefast import (
     NoneType,
 )
 from beartype._cave._cavemap import NoneTypeOr
-from beartype._util.data.hint.datahint import HINTS_IGNORABLE_SHALLOW
-from beartype_test.a00_unit.data.hint.pep.data_hintpep import (
+from beartype_test.a00_unit.data.hint.pep.data_pep import (
     HINTS_PEP_HASHABLE,
+    HINTS_PEP_IGNORABLE_SHALLOW,
     HINTS_PEP_IGNORABLE_DEEP,
 )
 
@@ -95,6 +95,10 @@ class NonPepCustomFakeTyping(object):
 NonPepCustomFakeTyping.__module__ = 'typing'
 
 # ....................{ NON-PEP ~ sets                    }....................
+# Note that we intentionally omit the "NonPepCustomFakeTyping" class here, as
+# that class masquerades too well as a "typing" class -- so well, in fact, that
+# "beartype._util.hint.pep.utilpeptest" functions are incapable of reasonably
+# distinguishing instances of that class from actual "typing" type hints.
 HINTS_NONPEP = frozenset((
     # Builtin container type.
     list,
@@ -133,9 +137,16 @@ NOT_HINTS_NONPEP = frozenset((
     # PEP-noncompliant type hints supported by @beartype, tuples containing
     # PEP-compliant type hints are invalid and thus unsupported.
     {
-        # Tuple containing a PEP-compliant type hint.
+        # Tuple containing this PEP-compliant type hint...
         (int, hint_pep_hashable, NoneType,)
+        # For each PEP-compliant type hint...
         for hint_pep_hashable in HINTS_PEP_HASHABLE
+        # That is *NOT* a string-based forward reference, which are a unique
+        # edge case supported as both PEP 484-compliant outside tuples *AND*
+        # beartype-specific inside tuples. Including such references here would
+        # erroneously cause tests to treat tuples containing string-based
+        # forward references as *NOT* beartype-specific type hints.
+        if not isinstance(hint_pep_hashable, str)
     } |
     # Set comprehension of hashable PEP-compliant non-class type hints.
     HINTS_PEP_HASHABLE |
@@ -161,8 +172,8 @@ well-known edge cases.
 
 # ....................{ NOT ~ tuples                      }....................
 HINTS_IGNORABLE = (
-    # Shallowly ignorable type hints.
-    HINTS_IGNORABLE_SHALLOW |
+    # Shallowly ignorable PEP-compliant type hints.
+    HINTS_PEP_IGNORABLE_SHALLOW |
     # Deeply ignorable PEP-compliant type hints.
     HINTS_PEP_IGNORABLE_DEEP
 )
